==> APMServices-SDK-iOS-1.5.3.tar.gz: APMServices-SDK-iOS-1.5.3/APMServices/Frameworks/APMServices.framework/Versions/A/Headers/APMServicesUtils.h <==
//
//  APMServicesUtils.h
//  APMServices
//
//  Created by Vincent Ducastel on 24/07/2015.
//  Copyright (c) 2015 Moonmiles. All rights reserved.
//

@interface APMServicesUtils : NSObject

+(void)debugLog:(NSString*)log;
+(void)debugLog:(NSString*)log force:(BOOL)force;
+(NSDate*)dateFromString:(NSString*)dateString dateFormat:(NSString*)dateFormat;
+(NSString*)stringFromDate:(NSDate*)date dateFormat:(NSString*)dateFormat;
+(void)store:(id)object def:(NSString*)def;
+(id)load:(NSString*)def;
+(void)remove:(NSString*)def;
+(NSDictionary*)paramsFromURL:(NSURL*)url;
+(BOOL)checkCoverage;
+(NSString*)schemeUrl;
+(BOOL)isSandbox;
+(void)showPopupLocationManager;
+(NSMutableArray*) createListActionsFromJsonActions:(NSDictionary*)actions;
+(NSString*)getAPMSchemeWithPartnerID:(NSString*)partnerID;
+(UIImage*)getPartnerIcon;
+(BOOL)emailValid:(NSString*)email;
+(NSMutableAttributedString*)getAttributedString:(NSString*)text withColor:(UIColor*)textColor andSize:(CGFloat)textSize andFont:(NSString*)textFont;
+(NSMutableAttributedString*)getAttributedStringFromSimpleHtml:(NSString*)text color:(NSString*)color size:(NSString*)size font:(NSString*)font;
+(NSString*)stringFromHtmlString:(NSString*)html;
+(NSInteger)getScreenWidth;
+(NSInteger)getScreenHeight;
+(NSInteger)getStatusBarWidth;
+(NSInteger)getStatusBarHeight;
+(float)radiansToDegrees:(float)radians;
+(float)degreesToRadians:(float)angle;
+(BOOL)isModal:(UIViewController*)controller;
+(BOOL)isWindowModal:(UIWindow*)window;
+(NSComparisonResult)systemVersionEqualTo:(NSString*)v;
+(NSComparisonResult)systemVersionGreaterThan:(NSString*)v;
+(NSComparisonResult)systemVersionGreaterThanOrEqualTo:(NSString*)v;
+(NSComparisonResult)systemVersionLessThan:(NSString*)v;
+(NSComparisonResult)systemVersionLessThanOrEqualTo:(NSString*)v;
+(NSComparisonResult)systemVersionXcodeLessThan:(NSString*)v;
+(NSMutableParagraphStyle*)createStyle:(CGFloat)lineHeightMultiple lineSpacing:(CGFloat)lineSpacing;
+(void)copy:(NSString*)copy;
+(NSString*)getLanguageCode;
+(UIView*)getCellFromCollectionView:(UIView*)tableView indexPath:(NSIndexPath*)indexPath;
+(UIColor*)uiColorFromHexaColor:(NSString*)hexaValue;
+(NSString *)hexStringFromColor:(UIColor *)color;
+(BOOL)isIos7;
+(BOOL)isIos9;
+(BOOL)isAtLeastIos10;
+(NSString*)stringUnicodeFromString:(NSString*)unicodeString;
+(NSString*)stringJsonFromDictionary:(NSDictionary*)jsonObject;
+(NSDictionary*)dictionaryFromStringJson:(NSString*)strValue;
+(NSInteger)heightContentWebView:(UIWebView*)webview;
+(NSString*)stringByStrippingHTML:(NSString*)string;
+(NSString*)nameOfApplication;

@end

==> APMServices-SDK-iOS-2.1.9.tar.gz: APMServices-SDK-iOS-2.1.9/APMServices/Frameworks/APMServices.framework/Versions/A/Headers/APMServicesUtils.h <==
//
//  APMServicesUtils.h
//  APMServices
//
//  Created by Vincent Ducastel on 24/07/2015.
//  Copyright (c) 2015 Moonmiles. All rights reserved.
//

@class APMUser;

@interface APMServicesUtils : NSObject

+(void)debugLog:(NSString*)log;
+(void)debugLog:(NSString*)log force:(BOOL)force;
+(NSDate*)dateFromString:(NSString*)dateString dateFormat:(NSString*)dateFormat;
+(NSString*)stringFromDate:(NSDate*)date dateFormat:(NSString*)dateFormat;
+(void)store:(id)object def:(NSString*)def;
+(id)load:(NSString*)def;
+(void)remove:(NSString*)def;
+(NSDictionary*)paramsFromURL:(NSURL*)url;
+(BOOL)checkCoverage;
+(BOOL)isSandbox;
+(NSMutableArray*) createListActionsFromJsonActions:(NSDictionary*)actions;
+(NSString*)getAPMSchemeWithPartnerID:(NSString*)partnerID;
+(UIImage*)getPartnerIcon;
+(BOOL)emailValid:(NSString*)email;
+(NSRegularExpressionOptions)regexOptionsFromStrFlags:(NSString*)flags;
+(NSMutableAttributedString*)getAttributedString:(NSString*)text withColor:(UIColor*)textColor andSize:(CGFloat)textSize andFont:(NSString*)textFont;
+(NSMutableAttributedString*)getAttributedStringFromSimpleHtml:(NSString*)text color:(NSString*)color size:(NSString*)size font:(NSString*)font;
+(NSString*)stringFromHtmlString:(NSString*)html;
+(NSInteger)getScreenWidth;
+(NSInteger)getScreenHeight;
+(NSInteger)getStatusBarWidth;
+(NSInteger)getStatusBarHeight;
+(BOOL)isIphoneX;
+(BOOL)isSmallIphone;
+(NSInteger)getBottomBarHeight;
+(float)radiansToDegrees:(float)radians;
+(float)degreesToRadians:(float)angle;
+(BOOL)isModal:(UIViewController*)controller;
+(BOOL)isWindowModal:(UIWindow*)window;
+(NSComparisonResult)systemVersionEqualTo:(NSString*)v;
+(NSComparisonResult)systemVersionGreaterThan:(NSString*)v;
+(NSComparisonResult)systemVersionGreaterThanOrEqualTo:(NSString*)v;
+(NSComparisonResult)systemVersionLessThan:(NSString*)v;
+(NSComparisonResult)systemVersionLessThanOrEqualTo:(NSString*)v;
+(NSComparisonResult)systemVersionXcodeLessThan:(NSString*)v;
+(NSMutableParagraphStyle*)createStyle:(CGFloat)lineHeightMultiple lineSpacing:(CGFloat)lineSpacing;
+(void)copy:(NSString*)copy;
+(NSString*)getCountryCode;
+(NSString*)getLanguageCode;
+(UIView*)getCellFromCollectionView:(UIView*)tableView indexPath:(NSIndexPath*)indexPath;
+(UIColor*)uiColorFromHexaColor:(NSString*)hexaValue;
+(NSString *)hexStringFromColor:(UIColor *)color;
+(BOOL)isIos7;
+(BOOL)isIos9;
+(BOOL)isAtLeastIos8;
+(BOOL)isAtLeastIos10;
+(NSString*)stringUnicodeFromString:(NSString*)unicodeString;
+(NSString*)stringJsonFromDictionary:(id)jsonObject;
+(id)dictionaryFromStringJson:(NSString*)strValue;
+(NSInteger)heightContentWebView:(UIWebView*)webview;
+(NSString*)stringByStrippingHTML:(NSString*)string;
+(NSString*)nameOfApplication;
+(BOOL)isEqual:(id)object1 object2:(id)object2;
+(APMUser*)copyUser:(APMUser*)user;
+(BOOL)isDatePast:(NSDate*)date withOffset:(double)offset;

@end
